@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -49,6 +49,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <math.h>
+#include <locale.h>
 #include <gconf/gconf-internals.h>
 #include <gconf/gconf-backend.h>
 
@@ -107,7 +108,7 @@ main (int argc, char** argv)
       gchar*  protocol;
       gchar*  resource;
       
-      flat_flags = g_strjoinv(",", iter->flags);
+      flat_flags = g_strjoinv (",", iter->flags);
 
       address = g_strconcat(iter->protocol, ":", flat_flags, ":", iter->resource, NULL);
 
